@@ -2,10 +2,10 @@
 
 readOGR <- function(dsn, layer, verbose=TRUE, p4s=NULL, 
         stringsAsFactors=default.stringsAsFactors(),
-        drop_unsupported_fields=FALSE, input_field_name_encoding=NULL,
+        drop_unsupported_fields=FALSE,
 	pointDropZ=FALSE, dropNULLGeometries=TRUE, useC=TRUE,
         disambiguateFIDs=FALSE, addCommentsToPolygons=TRUE, encoding=NULL,
-        use_iconv=NULL, swapAxisOrder=FALSE, require_geomType=NULL,
+        use_iconv=FALSE, swapAxisOrder=FALSE, require_geomType=NULL,
         integer64="allow.loss") {
 	if (missing(dsn)) stop("missing dsn")
 	if (nchar(dsn) == 0) stop("empty name")
@@ -19,9 +19,8 @@ readOGR <- function(dsn, layer, verbose=TRUE, p4s=NULL,
           "warn.loss"=2L, 
           "no.loss"=3L)
 # adding argument for SHAPE_ENCODING environment variable 121124
-        if (is.null(use_iconv))
-            use_iconv <- ifelse(as.integer(getGDALVersionInfo("VERSION_NUM"))
-                < 1900L, TRUE, FALSE)
+        stopifnot(is.logical(use_iconv))
+        stopifnot(length(use_iconv) == 1)
         if (!is.null(encoding)) {
             stopifnot(is.character(encoding))
             stopifnot(length(encoding) == 1)
@@ -34,14 +33,6 @@ readOGR <- function(dsn, layer, verbose=TRUE, p4s=NULL,
           m_require_geomType <- match(require_geomType, WKB)
           stopifnot(!is.na(m_require_geomType) || m_require_geomType <= 3)
         }
-        if (!is.null(input_field_name_encoding)) {
-            warning("input_field_name_encoding= deprecated, use encoding=")
-            stopifnot(is.character(input_field_name_encoding))
-            stopifnot(length(input_field_name_encoding) == 1)
-            if (!is.null(encoding) && (encoding != input_field_name_encoding))
-                stop("encoding and input_field_name_encoding differ")
-            if (is.null(encoding)) encoding <- input_field_name_encoding
-        }
         
 	suppressMessages(ogr_info <- ogrInfo(dsn=dsn, layer=layer,
             encoding=encoding, use_iconv=use_iconv,
@@ -158,18 +149,21 @@ readOGR <- function(dsn, layer, verbose=TRUE, p4s=NULL,
             dlist <- .Call("ogrDataFrame", as.character(dsn),
                 as.character(layer), as.integer(fids), iflds, PACKAGE="rgdal")
 	    names(dlist) <- make.names(fldnms ,unique=TRUE)
-# FIXME names
+
             if (use_iconv && !is.null(encoding)) {
                 for (i in seq(along=dlist)) {
-                    if (is.character(dlist[[i]]))
-                        dlist[[i]] <- iconv(dlist[[i]], from=encoding)
+                    if (is.character(dlist[[i]])) {
+                       dlist[[i]] <- iconv(dlist[[i]], from=encoding)
+                    }
                 }
             }
-            if (!use_iconv && !is.null(encoding) && 
-                ogr_info$driver == "ESRI Shapefile") {
-                tull <- setCPLConfigOption("SHAPE_ENCODING", oSE)
-            }
         }
+        if (!use_iconv && !is.null(encoding) && 
+            ogr_info$driver == "ESRI Shapefile") {
+            tull <- setCPLConfigOption("SHAPE_ENCODING", oSE)
+        }
+
+
 	geometry <- .Call("R_OGR_CAPI_features", as.character(dsn), 
 		as.character(layer), comments=addCommentsToPolygons,
                 PACKAGE="rgdal")
@@ -384,6 +378,7 @@ readOGR <- function(dsn, layer, verbose=TRUE, p4s=NULL,
 showWKT <- function(p4s, file=NULL, morphToESRI=TRUE) {
 
 	if (!is.character(p4s)) stop("invalid p4s object")
+        stopifnot(length(p4s) == 1)
 	if (!is.logical(morphToESRI)) stop("invalid morphToESRI object")
 	res <- .Call("p4s_to_wkt", as.character(p4s), as.integer(morphToESRI), 
 		PACKAGE="rgdal")
@@ -391,6 +386,17 @@ showWKT <- function(p4s, file=NULL, morphToESRI=TRUE) {
 	res
 }
 
+showP4 <- function(wkt, morphFromESRI=TRUE) {
+
+	if (!is.character(wkt)) stop("invalid wkt object")
+        stopifnot(length(wkt) == 1)
+	if (!is.logical(morphFromESRI)) stop("invalid morphFromESRI object")
+	res <- .Call("wkt_to_p4s", as.character(wkt),
+                as.integer(morphFromESRI), PACKAGE="rgdal")
+	res
+}
+
+
 showEPSG <- function(p4s) {
 
 	if (!is.character(p4s)) stop("invalid p4s object")
